KLDivergenceScheduler - LatentLego

Skip to content

# KLDivergenceScheduler

### `latent.callbacks.KLDivergenceScheduler`

Schedule Kullback-Leibler Divergence loss of VAEs during training.

#### `__init__(self, schedule, **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`schedule` | `Callable` | a function that takes an epoch index (integer, indexed from 0) and current KLD (float) as inputs and returns a new KLD as output (float). | required
`**kwargs` | `` | Other parameters passed to `keras.callbacks.Callback`. | `{}`